==> jboss-as-console-1.2.0.Final-sources.jar: org/jboss/as/console/client/domain/model/SimpleCallback.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @author tags. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */

package org.jboss.as.console.client.domain.model;

import com.allen_sauer.gwt.log.client.Log;
import com.google.gwt.user.client.rpc.AsyncCallback;
import org.jboss.as.console.client.Console;
import org.jboss.as.console.client.core.message.Message;

/**
 * @author Heiko Braun
 * @date 3/18/11
 */
public abstract class SimpleCallback<T> implements AsyncCallback<T> {

    @Override
    public void onFailure(Throwable caught) {
        Log.error("Unknown error", caught);
        Console.MODULES.getMessageCenter().notify(
                new Message("Unknown error", caught.getMessage(), Message.Severity.Error)
        );
    }
}

==> jboss-as-console-1.5.1.Final-sources.jar: org/jboss/as/console/client/domain/model/SimpleCallback.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @author tags. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */

package org.jboss.as.console.client.domain.model;

import com.allen_sauer.gwt.log.client.Log;
import com.google.gwt.user.client.rpc.AsyncCallback;
import org.jboss.as.console.client.Console;
import org.jboss.as.console.client.core.message.Message;
import org.jboss.as.console.client.debug.Diagnostics;

/**
 * @author Heiko Braun
 * @date 3/18/11
 */
public abstract class SimpleCallback<T> implements AsyncCallback<T> {

    @Override
    public void onFailure(Throwable caught) {
        Log.error("Unknown error", caught);
        Diagnostics.logError("dmr-invocation", System.currentTimeMillis(), caught.getMessage());
        Console.getMessageCenter().notify(
                new Message("Unknown error", caught.getMessage(), Message.Severity.Error)
        );
    }
}
